Matrix3

Struct Matrix3 

pub struct Matrix3 {
    pub data: [[f64; 3]; 3],
}
A 3×3 matrix stored in row-major order.

Fields

data: [[f64; 3]; 3]

Implementations

Source

impl Matrix3

pub const IDENTITY: Self

The 3×3 identity matrix.

pub fn rotation_x(theta: f64) -> Self

Rotation matrix about the X axis by theta radians.

Rx = | 1    0     0  |
     | 0   cos   sin |
     | 0  -sin   cos |
pub fn rotation_y(theta: f64) -> Self

Rotation matrix about the Y axis by theta radians.

Ry = |  cos  0  -sin |
     |   0   1    0  |
     |  sin  0   cos |
pub fn rotation_z(theta: f64) -> Self

Rotation matrix about the Z axis by theta radians.

Rz = |  cos  sin  0 |
     | -sin  cos  0 |
     |   0    0   1 |
pub fn transpose(&self) -> Self

Returns the transpose of this matrix.

pub fn multiply(&self, other: &Self) -> Self

Returns the matrix product self * other.

pub fn apply(&self, v: &Vector3) -> Vector3

Applies this matrix to a vector, returning self * v.